@@ -13,7 +13,7 @@ def test_query_single_table(snapshot, seeded_session, rewriter):
     """Query with one table"""
     test_query: Query = seeded_session.query(SDChild)
 
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query.statement)))
     snapshot.assert_match(sorted(test_query.all(), key=lambda i: i.id))
 
 
@@ -21,7 +21,7 @@ def test_query_with_join(snapshot, seeded_session, rewriter):
     """Query with a simple join"""
     test_query: Query = seeded_session.query(SDChild).join(SDParent)  # noqa -- wrong typing stub in SA
 
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query.statement)))
 
     snapshot.assert_match(sorted(test_query.all(), key=lambda i: i.id))
 
@@ -30,11 +30,22 @@ def test_query_union_sdchild(snapshot, seeded_session, rewriter):
     """Two queries joined via UNION"""
     test_query: Query = seeded_session.query(SDChild).union(seeded_session.query(SDChild))
 
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query.statement)))
 
     snapshot.assert_match(sorted(test_query.all(), key=lambda i: i.id))
 
 
+def test_query_union_sdchild_core(snapshot, seeded_session, rewriter):
+    """Two queries joined via UNION, using SQLAlchemy Core"""
+    sdchild = SDChild.__table__
+
+    select_as_core = (select(sdchild.c.id, sdchild.c.parent_id).select_from(sdchild)).union(
+        select(sdchild.c.id, sdchild.c.parent_id).select_from(sdchild)
+    )
+
+    snapshot.assert_match(str(rewriter.rewrite_statement(select_as_core)))
+
+
 def test_query_with_union_but_union_softdelete_disabled(snapshot, seeded_session, rewriter):
     """Two queries joined via UNION but the second one has soft-delete disabled"""
 
@@ -47,7 +58,7 @@ def test_query_with_union_but_union_softdelete_disabled(snapshot, seeded_session
         seeded_session.query(SDChild).execution_options(include_deleted=True)
     )
 
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query.statement)))
 
     all_children: List[SDChild] = seeded_session.query(SDChild).execution_options(include_deleted=True).all()
 
@@ -60,14 +71,14 @@ def test_ensure_aggregate_from_multiple_table_deletion_works_active_object_count
     """Aggregate function from a query that contains a join"""
     test_query: Query = seeded_session.query(SDChild).join(SDParent).with_entities(func.count())  # noqa
 
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query.statement)))
     snapshot.assert_match(test_query.count())
 
 
 def test_ensure_table_with_inheritance_works(snapshot, seeded_session, rewriter):
     test_query: Query = seeded_session.query(SDDerivedRequest)
 
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query.statement)))
 
     test_query_results = test_query.all()
     assert len(test_query_results) == 2
@@ -105,7 +116,7 @@ def test_query_with_text_clause_as_table(snapshot, seeded_session, rewriter):
 
     # Table as a TextClause
     test_query_text_clause: Select = select(text('id')).select_from(text("sdderivedrequest"))
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query_text_clause)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query_text_clause)))
 
 
 def test_query_with_table_clause_as_table(snapshot, seeded_session, rewriter):
@@ -113,7 +124,7 @@ def test_query_with_table_clause_as_table(snapshot, seeded_session, rewriter):
 
     # Table as a TableClause
     test_query_table_clause: Select = select(text('id')).select_from(table("sdderivedrequest"))
-    snapshot.assert_match(str(rewriter.rewrite_select(test_query_table_clause)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(test_query_table_clause)))
 
 
 def test_insert_with_returning(snapshot, seeded_session, rewriter, db_connection):
@@ -144,4 +155,4 @@ def test_query_with_more_than_one_join(snapshot, seeded_session, rewriter):
         )
     )
 
-    snapshot.assert_match(str(rewriter.rewrite_select(query.statement)))
+    snapshot.assert_match(str(rewriter.rewrite_statement(query.statement)))
